@@ -6,13 +6,97 @@ import os
 
 class ContextTests(unittest.TestCase):
 
-    noise = True
+    noise = False
     def _print(self, text:str) -> None:
         if self.noise:
             print(text)
 
     def off(self) -> bool:
-        return True
+        return False
+
+    def test_split_plus_concat(self):
+        # tests the use of:
+        #    split-plus searches
+        #    non-split-plus searches
+        #    split-plus searches with roots that deny split-plus
+        #    implicitly, the order of multi-root searches
+        # see config.ini re: order of roots under [doc] in the
+        # context of split-plus searches
+        docpath = "app/home/teams#delete_assignee+todo"
+        metadata = ContextMetadata()
+        context = Context(metadata)
+
+        # split plus: true
+        #    both roots allow split plus
+        doc = context.get_doc(docpath)
+        print(f"\nContextTests.test_split_plus_concat: doc 1:\n{doc}")
+        self.assertIsNotNone(doc, msg=f"doc at {docpath} must not be none")
+        found = doc.find("edit assignee") > -1
+        found = found and doc.find("my app name: you should see") > -1
+        self.assertEqual(found, True, msg=f"doc: {doc} doesn't have expected content")
+
+        # split plus: false
+        #    both roots allow split plus
+        doc = context.get_doc(docpath, False, False)
+        print(f"\nContextTests.test_split_plus_concat: doc 2:\n{doc}")
+        found = doc.find("edit assignee") > -1
+        found = found and doc.find("my app name: you should see") > -1
+        self.assertEqual(found, False, msg=f"doc: {doc} doesn't have expected content")
+
+        context._nosplitplus = ['internal','public']
+
+        # split plus: true
+        #    both roots deny split plus
+        doc = context.get_doc(docpath)
+        print(f"\nContextTests.test_split_plus_concat: doc 3:\n{doc}")
+        self.assertIsNotNone(doc, msg=f"doc at {docpath} must not be none")
+        found = doc.find("edit assignee") == -1
+        found = found and doc.find("my app name: you should see") == -1
+        self.assertEqual(found, True, msg=f"doc: {doc} doesn't have expected content")
+        # split plus: false
+        #    both roots deny split plus
+        doc = context.get_doc(docpath, False, False)
+        print(f"\nContextTests.test_split_plus_concat: doc 4:\n{doc}")
+        found = doc.find("edit assignee") == -1
+        found = found and doc.find("my app name: you should see") == -1
+        self.assertEqual(found, False, msg=f"doc: {doc} doesn't have expected content")
+
+        context._nosplitplus = ['public']
+
+        # split plus: true
+        #    public denies split plus
+        doc = context.get_doc(docpath)
+        print(f"\nContextTests.test_split_plus_concat: doc 5:\n{doc}")
+        self.assertIsNotNone(doc, msg=f"doc at {docpath} must not be none")
+        found = doc.find("edit assignee") > -1
+        found = found and doc.find("my app name: you should see") == -1
+        self.assertEqual(found, True, msg=f"doc: {doc} doesn't have expected content")
+        # split plus: false
+        #    public denies split plus
+        doc = context.get_doc(docpath, False, False)
+        print(f"\nContextTests.test_split_plus_concat: doc 6:\n{doc}")
+        found = doc.find("edit assignee") == -1
+        found = found and doc.find("my app name: you should see") > -1
+        self.assertEqual(found, True, msg=f"doc: {doc} doesn't have expected content")
+
+        context._nosplitplus = ['internal']
+
+        # split plus: true
+        #    internal denies split plus
+        doc = context.get_doc(docpath)
+        print(f"\nContextTests.test_split_plus_concat: doc 7:\n{doc}")
+        self.assertIsNotNone(doc, msg=f"doc at {docpath} must not be none")
+        found = doc.find("edit assignee") == -1
+        found = found and doc.find("my app name: you should see") > -1
+        self.assertEqual(found, True, msg=f"doc: {doc} doesn't have expected content")
+
+        # split plus: false
+        #    internal denies split plus
+        doc = context.get_doc(docpath, False, False)
+        print(f"\nContextTests.test_split_plus_concat: doc 8:\n{doc}")
+        found = doc.find("edit assignee") == -1
+        found = found and doc.find("my app name: you should see") > -1
+        self.assertEqual(found, True, msg=f"doc: {doc} doesn't have expected content")
 
     def test_roots(self):
         self._print("ContextTests.test_roots")
@@ -44,7 +128,7 @@ class ContextTests(unittest.TestCase):
         accceptedby = metadata.accepted_by
         self._print(f"accceptedby: {accceptedby}")
         self.assertIsNotNone( accceptedby, msg="accceptedby must not be None")
-        self.assertEqual(len(accceptedby), 7, msg=f"must be 6 keys in accceptedby, not {accceptedby}")
+        self.assertEqual(len(accceptedby), 7, msg=f"must be 7 keys in accceptedby, not {accceptedby}")
         self.assertIsNotNone( accceptedby["cdocs"], msg="accepts must have a 'cdocs' key")
         cdocs = accceptedby["cdocs"]
         self.assertEqual(len(cdocs), 2, msg="must be 2 items in cdocs")
@@ -125,27 +209,26 @@ class ContextTests(unittest.TestCase):
         point = txt.find("my app name: you should see: my app's name is fruit")
         self.assertNotEqual(-1,point, msg="must include 'my app name: you should see: my app's name is fruit'")
 
-
     def test_get_doc_just_checking(self) :
         self._print(f"ContextTests.test_get_doc_just_checking")
-        #if self.off(): return
+        if self.off(): return
         metadata = ContextMetadata()
         context = Context(metadata)
         docpath = "/app/home/teams*delete_assignee"
         txt = context.get_doc(docpath)
+        # this doc could be a not-found doc. for what I need today that's fine.
         self.assertIsNotNone(txt, msg=f"doc at {docpath} must not be none")
         self._print(f"ContextTests.test_get_doc_just_checking: doing get_docs. the doc txt is: {txt}")
 
-
-
     def test_get_labels(self):
         self._print(f"ContextTests.test_get_labels")
         if self.off(): return
         docpath = "/app/home/teams/todos/assignee"
+        #docpath = "/v1/test/fish"
         metadata = ContextMetadata()
         context = Context(metadata)
         labels = context.get_labels(docpath)
-        self._print(f"test_get_labels: the labels are: {labels}")
+        print(f"test_get_labels: the labels are: {labels}")
         self.assertIn("app", labels, msg=f"labels at {docpath} must include key 'app'")
         self.assertIn("team", labels, msg=f"labels at {docpath} must include key 'team'")
         self.assertIn("my_app_name", labels, msg=f"labels at {docpath} must include key 'my_app_name'")
@@ -158,7 +241,7 @@ class ContextTests(unittest.TestCase):
         metadata = ContextMetadata()
         context = Context(metadata)
         docpath = "/app/home/teams/todos/assignee"
-        txt = context.get_doc_from_roots(["images"], docpath)
+        txt = context.get_doc_from_roots(["images"], docpath, False)
         self.assertIsNone(txt, msg=f"doc at {docpath} in root 'images' must be none")
 
     def test_get_doc_from_right_root(self) :
@@ -177,7 +260,7 @@ class ContextTests(unittest.TestCase):
         docpath = "/app/home/teams"
         metadata = ContextMetadata()
         context = Context(metadata)
-        doc = context.get_doc_from_roots(["internal"], docpath)
+        doc = context.get_doc_from_roots(["internal"], docpath, False)
         self._print(f"test_get_compose_doc_with_roots: doc from 'internal': {doc}")
         assignee = doc.find('assignee in company starstruck!')
         self.assertNotEqual(-1, assignee, msg=f'{docpath} must include "assignee in company starstruck!" in {doc}')
